<?php

/*
  Plugin Name: DeMomentSomTres Grid Archive
  Plugin URI: http://demomentsomtres.com/
  Description: Displays archives in a month grid with post counts for each month, with yearly and grand totals, and shows titles and comment counts for all posts.
  Version: 2.1
  Author: marcqueralt
  Author URI: http://demomentsomtres.com
  License: GPLv2 or later
 */

// Create a helper function for easy SDK access.
function dms3gridarchive_fs() {
    global $dms3gridarchive_fs;

    if (!isset($dms3gridarchive_fs)) {
        // Include Freemius SDK.
        require_once dirname(__FILE__) . '/freemius/start.php';

        $dms3gridarchive_fs = fs_dynamic_init(array(
            'id' => '533',
            'slug' => 'demomentsomtres-grid-archive',
            'type' => 'plugin',
            'public_key' => 'pk_33fb9b3ada81475e9f14c18a6f9a7',
            'is_premium' => false,
            'has_addons' => false,
            'has_paid_plans' => false,
            'menu' => array(
                'account' => false,
                'contact' => false,
                'support' => false,
            ),
                ));
    }

    return $dms3gridarchive_fs;
}

// Init Freemius.
dms3gridarchive_fs();

add_shortcode('DeMomentSomTres-Grid-Archive', 'demomentsomtres_grid_archive_shortcode');

/**
 * Generates all the content of the shortcode
 * @param mixed $atts
 * @return string
 * @since 1.0
 */
function demomentsomtres_grid_archive_shortcode($atts) {
    extract(shortcode_atts(array(
        'style' => '',
        'first_header' => '',
                    ), $atts));
    return demomentsomtres_month_grid_archive($style, $first_header);
}

/* Start of code adapted from the french archives: 
  http://rmarsh.com/plugins/compact-archives/
  Which points to source:
  http://justinblanton.com/projects/smartarchives/
  http://wpguy.com/articles/an-archives-page-with-all-the-posts-in-cronological-order/
 */

/**
 * Generates the grid
 * @global mixed $wpdb
 * @global mixed $wp_version
 * @param string $style
 * @param string $first_header
 * @return string the html containing all the information
 */
function demomentsomtres_month_grid_archive($style = 'abbr', $first_header = 'Monthly') {
    global $wpdb, $wp_version;
    if (WPLANG == 'ca'):
        $lang = 'ca_ES';
    else:
        $lang = WPLANG;
    endif;
    setlocale(LC_ALL, $lang); // set localization language

    $year_results = $wpdb->get_results("SELECT distinct year(post_date) as year
		FROM $wpdb->posts
		WHERE post_status='publish'
		AND post_password=''
		AND post_type='post'
		ORDER BY year desc");
    $output = '';
    if (!$year_results) {
        $output .= '';
    }
    if (!empty($first_header)) {
        $first_header = '<tr><th class="hdr1" colspan="14">' .
                "$first_header</th></tr>\n";
    }
    $output .= '<table id="dms3-month-grid" class="table table-bordered table-striped table-hover">' . "\n$first_header<tr><th>&nbsp;</th>\n";

    for ($month = 1; $month <= 12; $month += 1) {
        $dummydate = strtotime("$month/01/2001");
        // get the month name; strftime() localizes
        $month_name = date_i18n("F",$dummydate);
        switch ($style) {
            case 'initial':
                $month_hdr = $month_name[0]; // the inital of the month
                break;
            case 'numeric':
                $month_hdr = strftime("%m", $dummydate); // get the month number, e.g., '04'
                break;
            default:
                $month_hdr = date_i18n("M",$dummydate);
                        //strftime("%b", $dummydate); // get the short month name; strftime() localizes
        }
        $output .= '<th class="hdr2">' . $month_hdr . "</th>\n";
    }
    $output .= "<th>" . _('Total') . "</th></tr>\n";

    $grand_total = 0;
    $num_years = 0;
    foreach ($year_results as $year_result) {
        $num_years += 1;
        $year = $year_result->year;
        if ($year == 0)
            continue;
        $output .= '<tr><td class="year"><a href="' . get_year_link($year) . '">' . $year . "</a></td>\n";
        $year_total_post_count = 0;

        for ($month = 1; $month <= 12; $month += 1) {
            $num_posts_in_month = $wpdb->get_var("SELECT count(*)
				FROM $wpdb->posts
				WHERE year(post_date)='$year'
				AND month(post_date)='$month'
				AND post_status='publish'
				AND post_password=''
				AND post_type='post'");

            $year_total_post_count += $num_posts_in_month;

            $dummydate = strtotime("$month/01/2001");
            // get the month name; strftime() localizes
            $month_name = strftime("%B", $dummydate);

            if ($num_posts_in_month > 0) {
                $output .= '<td class="count"><a href="' . get_month_link($year, $month) . '" title="' . $month_name . ' ' . $year . '">' . $num_posts_in_month . "</a></td>\n";
            } else {
                $output .= "<td>&nbsp;</td>\n";
            }
        }
        $output .= '<td class="total">' . $year_total_post_count . "</td></tr>\n";
        $grand_total += $year_total_post_count;
    }
    if ($num_years > 1) { // only show grand total if more than one year
        $output .= '<tr><th colspan="13">&nbsp;</th><th class="total">' . $grand_total . "</th></tr>\n";
    } else {
        $output .= '<tr><th colspan="14">&nbsp;</th></tr>' . "\n";
    }
    $output .= "</table>\n";
    return $output;
}

/* End of code from the french archives */
?>